==> hlw-core-0.0.2-20250422.075438-9-sources.jar: cn/gtmap/hlw/core/model/GxYyFjxxZxgl.java <==
package cn.gtmap.hlw.core.model;

import com.baomidou.mybatisplus.extension.activerecord.Model;

import java.io.Serializable;
import java.util.Date;

/**
 * 新闻资讯附件表(GxYyFjxxZxgl)表实体类
 *
 * @author makejava
 * @since 2024-01-26 17:34:14
 */
@SuppressWarnings("serial")
public class GxYyFjxxZxgl extends Model<GxYyFjxxZxgl> {

    private String id;

    private String mc;

    private String bz;

    private Integer enabled;

    private String pathHead;

    private String pathBody;
    /**物理磁盘位置*/
    private String discPath;
    /**文件名带后缀*/
    private String mcHz;

    private Date createAt;

    private Date updateAt;

    private String userId;
     /**预约号（关联gx_yy_custom_news.id）*/
    private String newsId;
     /**附件编号*/
    private String fjbh;


    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getMc() {
        return mc;
    }

    public void setMc(String mc) {
        this.mc = mc;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Integer getEnabled() {
        return enabled;
    }

    public void setEnabled(Integer enabled) {
        this.enabled = enabled;
    }

    public String getPathHead() {
        return pathHead;
    }

    public void setPathHead(String pathHead) {
        this.pathHead = pathHead;
    }

    public String getPathBody() {
        return pathBody;
    }

    public void setPathBody(String pathBody) {
        this.pathBody = pathBody;
    }

    public String getDiscPath() {
        return discPath;
    }

    public void setDiscPath(String discPath) {
        this.discPath = discPath;
    }

    public String getMcHz() {
        return mcHz;
    }

    public void setMcHz(String mcHz) {
        this.mcHz = mcHz;
    }

    public Date getCreateAt() {
        return createAt;
    }

    public void setCreateAt(Date createAt) {
        this.createAt = createAt;
    }

    public Date getUpdateAt() {
        return updateAt;
    }

    public void setUpdateAt(Date updateAt) {
        this.updateAt = updateAt;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getNewsId() {
        return newsId;
    }

    public void setNewsId(String newsId) {
        this.newsId = newsId;
    }

    public String getFjbh() {
        return fjbh;
    }

    public void setFjbh(String fjbh) {
        this.fjbh = fjbh;
    }

    /**
     * 获取主键值
     *
     * @return 主键值
     */
    @Override
    protected Serializable pkVal() {
        return this.id;
    }
}

==> hlw-core-0.0.2-20251021.104452-156-sources.jar: cn/gtmap/hlw/core/model/GxYyFjxxZxgl.java <==
package cn.gtmap.hlw.core.model;

import com.baomidou.mybatisplus.extension.activerecord.Model;

import java.io.Serializable;
import java.util.Date;

/**
 * 新闻资讯附件表(GxYyFjxxZxgl)表实体类
 *
 * @author makejava
 * @since 2024-01-26 17:34:14
 */
@SuppressWarnings("serial")
public class GxYyFjxxZxgl extends Model<GxYyFjxxZxgl> {

    private String id;

    private String mc;

    private String bz;

    private Integer enabled;

    private String pathHead;

    private String pathBody;
    /**物理磁盘位置*/
    private String discPath;
    /**文件名带后缀*/
    private String mcHz;

    private Date createAt;

    private Date updateAt;

    private String userId;
     /**预约号（关联gx_yy_custom_news.id）*/
    private String newsId;
     /**附件编号*/
    private String fjbh;


    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getMc() {
        return mc;
    }

    public void setMc(String mc) {
        this.mc = mc;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Integer getEnabled() {
        return enabled;
    }

    public void setEnabled(Integer enabled) {
        this.enabled = enabled;
    }

    public String getPathHead() {
        return pathHead;
    }

    public void setPathHead(String pathHead) {
        this.pathHead = pathHead;
    }

    public String getPathBody() {
        return pathBody;
    }

    public void setPathBody(String pathBody) {
        this.pathBody = pathBody;
    }

    public String getDiscPath() {
        return discPath;
    }

    public void setDiscPath(String discPath) {
        this.discPath = discPath;
    }

    public String getMcHz() {
        return mcHz;
    }

    public void setMcHz(String mcHz) {
        this.mcHz = mcHz;
    }

    public Date getCreateAt() {
        return createAt;
    }

    public void setCreateAt(Date createAt) {
        this.createAt = createAt;
    }

    public Date getUpdateAt() {
        return updateAt;
    }

    public void setUpdateAt(Date updateAt) {
        this.updateAt = updateAt;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getNewsId() {
        return newsId;
    }

    public void setNewsId(String newsId) {
        this.newsId = newsId;
    }

    public String getFjbh() {
        return fjbh;
    }

    public void setFjbh(String fjbh) {
        this.fjbh = fjbh;
    }

    /**
     * 获取主键值
     *
     * @return 主键值
     */
    @Override
    public Serializable pkVal() {
        return this.id;
    }
}
